@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2020 The pyXem developers
+# Copyright 2016-2021 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -15,12 +15,11 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with pyXem.  If not, see <http://www.gnu.org/licenses/>.
-"""Signal class for two-dimensional diffraction variance.
+"""Signal class for two-dimensional diffraction variance."""
 
-"""
+from hyperspy.signals import Signal2D
 
 from pyxem.signals.diffraction2d import Diffraction2D
-from hyperspy.signals import Signal2D
 
 
 class DiffractionVariance2D(Diffraction2D):
