@@ -1290,7 +1290,7 @@ class TestFindHotPixels:
         assert not s_hot_pixels.data.any()
 
     def test_mask_array(self, hot_pixel_data_2d):
-        mask_array = np.ones_like(hot_pixel_data_2d.data, dtype=np.bool)
+        mask_array = np.ones_like(hot_pixel_data_2d.data, dtype=bool)
         s_hot_pixels = hot_pixel_data_2d.find_hot_pixels(mask_array=mask_array)
         assert not s_hot_pixels.data.any()
 
@@ -1347,7 +1347,7 @@ class TestFindDeadPixels:
         assert not s_dead_pixels.data.any()
 
     def test_mask_array(self, dead_pixel_data_2d):
-        mask_array = np.ones_like(dead_pixel_data_2d.data, dtype=np.bool)
+        mask_array = np.ones_like(dead_pixel_data_2d.data, dtype=bool)
         s_dead_pixels = dead_pixel_data_2d.find_dead_pixels(mask_array=mask_array)
         assert not s_dead_pixels.data.any()
 
