@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2020 The pyXem developers
+# Copyright 2016-2021 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -20,21 +20,15 @@ import numpy as np
 import scipy.ndimage as ndi
 import pyxem as pxm  # for ElectronDiffraction2D
 
-from scipy.ndimage.interpolation import shift
 from scipy.interpolate import interp1d
-from scipy.optimize import curve_fit, minimize
 from skimage import transform as tf
 from skimage import morphology, filters
-from skimage.morphology import square, opening
 from skimage.draw import ellipse_perimeter
-from skimage.feature import register_translation
-from scipy.optimize import curve_fit
+from skimage.registration import phase_cross_correlation
 from tqdm import tqdm
 
 from pyxem.utils.pyfai_utils import get_azimuthal_integrator
 
-from pyFAI.azimuthalIntegrator import AzimuthalIntegrator
-
 
 """
 This module contains utility functions for processing electron diffraction
@@ -43,7 +37,7 @@ patterns.
 
 
 def _index_coords(z, origin=None):
-    """Creates x & y coords for the indicies in a numpy array.
+    """Creates x & y coords for the indices in a numpy array.
 
     Parameters
     ----------
@@ -109,190 +103,8 @@ def _polar2cart(r, theta):
     return x, y
 
 
-def azimuthal_integrate1d_slow(
-    z,
-    detector_distance,
-    detector,
-    npt_rad,
-    wavelength=None,
-    unit="2th_rad",
-    center=None,
-    mask=None,
-    affine=None,
-    method="splitpixel",
-    correctSolidAngle=True,
-    radial_range=None,
-    azimuth_range=None,
-    azimuthal_kwargs={},
-    integrate_kwargs={},
-):
-    """Calculate the azimuthal integral in 2d around a determined origin.
-
-    This method is used for signals where the origin is iterated, compared to
-    azimuthal_integrate_fast which is used when the origin, mask and affine transformation in the data is
-    constant.
-
-    Parameters
-    ----------
-    z : np.array()
-        Two-dimensional data array containing the signal.
-    origin : np.array()
-        A size 2 numpy array containing the position of the origin.
-    detector_distance : float
-        Detector distance in meters passed to pyFAI AzimuthalIntegrator.
-    detector : pyFAI.detectors.Detector object
-        A pyFAI detector used for the AzimuthalIntegrator.
-    wavelength : float
-        The electron wavelength in meters. Used by pyFAI AzimuthalIntegrator.
-    size_1d : int
-        The size of the returned 1D signal. (i.e. number of pixels in the 1D
-        azimuthal integral.)
-    unit : str
-        The unit for for PyFAI integrate1d.
-    *args :
-        Arguments to be passed to AzimuthalIntegrator.
-    **kwargs :
-        Keyword arguments to be passed to AzimuthalIntegrator.
-    Returns
-    -------
-    tth : np.array()
-        One-dimensional scattering vector axis of z.
-    I : np.array()
-        One-dimensional azimuthal integral of z.
-    """
-    shape = np.shape(z)
-    ai = get_azimuthal_integrator(
-        detector=detector,
-        detector_distance=detector_distance,
-        shape=shape,
-        center=center,
-        affine=affine,
-        mask=mask,
-        wavelength=wavelength,
-        **azimuthal_kwargs
-    )
-    output = ai.integrate1d(
-        z,
-        npt=npt_rad,
-        method=method,
-        unit=unit,
-        correctSolidAngle=correctSolidAngle,
-        azimuth_range=azimuth_range,
-        radial_range=radial_range,
-        **integrate_kwargs
-    )
-    return output[1]
-
-
-def azimuthal_integrate1d_fast(z, azimuthal_integrator, npt_rad, **kwargs):
-    """Calculate the azimuthal integral of z around a determined origin.
-
-    This method is used for signals where the origin is constant, compared to
-    azimuthal_integrate which is used when the origin in the data changes and
-    is iterated over.
-
-    Parameters
-    ----------
-    z : np.array()
-        Two-dimensional data array containing the signal.
-    azimuthal_integrator : pyFAI.azimuthal_integrator.AzimuthalIntegrator object
-        An AzimuthalIntegrator that is already initialised and used to calculate
-        the integral.
-    npt_rad:
-        The number of radial points to integrate
-    **kwargs :
-        Keyword arguments to be passed to ai.integrate2d
-    Returns
-    -------
-    tth : np.array()
-        One-dimensional scattering vector axis of z.
-    I : np.array()
-        One-dimensional azimuthal integral of z.
-    """
-    output = azimuthal_integrator.integrate1d(z, npt=npt_rad, **kwargs)
-    return output[1]
-
-
-def azimuthal_integrate2d_slow(
-    z,
-    detector_distance,
-    detector,
-    npt_rad,
-    npt_azim=360,
-    wavelength=None,
-    unit="2th_rad",
-    center=None,
-    mask=None,
-    affine=None,
-    method="splitpixel",
-    correctSolidAngle=True,
-    radial_range=None,
-    azimuth_range=None,
-    azimuthal_kwargs={},
-    integrate_kwargs={},
-):
-    """Calculate the azimuthal integral in 2d around a determined origin.
-
-    This method is used for signals where the origin is iterated, compared to
-    azimuthal_integrate_fast which is used when the origin, mask and affine transformation in the data is
-    constant.
-
-    Parameters
-    ----------
-    z : np.array()
-        Two-dimensional data array containing the signal.
-    origin : np.array()
-        A size 2 numpy array containing the position of the origin.
-    detector_distance : float
-        Detector distance in meters passed to pyFAI AzimuthalIntegrator.
-    detector : pyFAI.detectors.Detector object
-        A pyFAI detector used for the AzimuthalIntegrator.
-    wavelength : float
-        The electron wavelength in meters. Used by pyFAI AzimuthalIntegrator.
-    size_1d : int
-        The size of the returned 1D signal. (i.e. number of pixels in the 1D
-        azimuthal integral.)
-    unit : str
-        The unit for for PyFAI integrate1d.
-    *args :
-        Arguments to be passed to AzimuthalIntegrator.
-    **kwargs :
-        Keyword arguments to be passed to AzimuthalIntegrator.
-    Returns
-    -------
-    tth : np.array()
-        One-dimensional scattering vector axis of z.
-    I : np.array()
-        One-dimensional azimuthal integral of z.
-    """
-    shape = np.shape(z)
-    ai = get_azimuthal_integrator(
-        detector=detector,
-        detector_distance=detector_distance,
-        shape=shape,
-        center=center,
-        affine=affine,
-        mask=mask,
-        wavelength=wavelength,
-        **azimuthal_kwargs
-    )
-
-    output = ai.integrate2d(
-        z,
-        npt_rad=npt_rad,
-        npt_azim=npt_azim,
-        method=method,
-        unit=unit,
-        correctSolidAngle=correctSolidAngle,
-        azimuth_range=azimuth_range,
-        radial_range=radial_range,
-        **integrate_kwargs
-    )
-    return np.transpose(output[0])
-
-
-def azimuthal_integrate2d_fast(
-    z, azimuthal_integrator, npt_rad, npt_azim=None, **kwargs
+def azimuthal_integrate1d(
+    z, azimuthal_integrator, npt_rad, mask=None, sum=False, **kwargs
 ):
     """Calculate the azimuthal integral of z around a determined origin.
 
@@ -309,8 +121,13 @@ def azimuthal_integrate2d_fast(
         the integral.
     npt_rad:
         The number of radial points to integrate
+    mask: Boolean Array
+        A boolean array with pixels to ignore
+    sum: bool
+        Returns the integrated intensity rather than the mean.
     **kwargs :
         Keyword arguments to be passed to ai.integrate2d
+
     Returns
     -------
     tth : np.array()
@@ -318,10 +135,161 @@ def azimuthal_integrate2d_fast(
     I : np.array()
         One-dimensional azimuthal integral of z.
     """
+    output = azimuthal_integrator.integrate1d(z, npt=npt_rad, mask=mask, **kwargs)
+    if sum:
+        return np.transpose(output._sum_signal)
+    else:
+        return output[1]
+
+
+def azimuthal_integrate2d(
+    z, azimuthal_integrator, npt_rad, npt_azim=None, mask=None, sum=False, **kwargs
+):
+    """Calculate the azimuthal integral of z around a determined origin.
+
+    This method is used for signals where the origin is constant, compared to
+    azimuthal_integrate which is used when the origin in the data changes and
+    is iterated over.
+
+    Parameters
+    ----------
+    z : np.array()
+        Two-dimensional data array containing the signal.
+    azimuthal_integrator : pyFAI.azimuthal_integrator.AzimuthalIntegrator object
+        An AzimuthalIntegrator that is already initialised and used to calculate
+        the integral.
+    npt_rad: int
+        The number of radial points to integrate
+    npt_azim: int
+        The number of azimuthal points to integrate
+    mask: Boolean Array
+        The mask used to ignore points.
+    sum: bool
+        If True the sum is returned, otherwise the average is returned.
+    **kwargs :
+        Keyword arguments to be passed to ai.integrate2d
+
+    Returns
+    -------
+    I : np.array()
+        Two-dimensional azimuthal integral of z.
+    """
     output = azimuthal_integrator.integrate2d(
-        z, npt_rad=npt_rad, npt_azim=npt_azim, **kwargs
+        z, npt_rad=npt_rad, npt_azim=npt_azim, mask=mask, **kwargs
     )
-    return np.transpose(output[0])
+    if sum:
+        return np.transpose(output._sum_signal)
+    else:
+        return np.transpose(output[0])
+
+
+def integrate_radially(
+    z, azimuthal_integrator, npt, npt_rad, mask=None, sum=False, **kwargs
+):
+    """Calculate the radial integrated profile curve as I = f(chi)
+
+    Parameters
+    ----------
+    z : np.array()
+        Two-dimensional data array containing the signal.
+    azimuthal_integrator : pyFAI.azimuthal_integrator.AzimuthalIntegrator object
+        An AzimuthalIntegrator that is already initialised and used to calculate
+        the integral.
+    npt: int
+         The number of points in the output pattern
+    npt_rad: int
+        The number of points in the radial space. Too few points may lead to huge rounding errors.
+    mask: Boolean Array
+        A boolean array with pixels to ignore
+    sum: bool
+        Returns the integrated intensity rather than the mean.
+    **kwargs :
+        Keyword arguments to be passed to ai.integrate2d
+
+    Returns
+    -------
+    tth : np.array()
+        One-dimensional scattering vector axis of z.
+    I : np.array()
+        One-dimensional azimuthal integral of z.
+    """
+    output = azimuthal_integrator.integrate_radial(
+        z, npt=npt, npt_rad=npt_rad, mask=mask, **kwargs
+    )
+    if sum:
+        return np.transpose(output._sum_signal)
+    else:
+        return output[1]
+
+
+def medfilt_1d(z, azimuthal_integrator, npt_rad, npt_azim, mask=None, **kwargs):
+    """Perform the 2D integration and filter along each row using a median filter
+
+    Parameters
+    ----------
+    z : np.array()
+        Two-dimensional data array containing the signal.
+    azimuthal_integrator : pyFAI.azimuthal_integrator.AzimuthalIntegrator object
+        An AzimuthalIntegrator that is already initialised and used to calculate
+        the integral.
+    npt: int
+         The number of points in the output pattern
+    npt_rad: int
+        The number of points in the radial space. Too few points may lead to huge rounding errors.
+    mask: Boolean Array
+        A boolean array with pixels to ignore
+    sum: bool
+        Returns the integrated intensity rather than the mean.
+    **kwargs :
+        Keyword arguments to be passed to ai.integrate2d
+
+    Returns
+    -------
+    tth : np.array()
+        One-dimensional scattering vector axis of z.
+    I : np.array()
+        One-dimensional azimuthal integral of z.
+    """
+    output = azimuthal_integrator.medfilt1d(
+        z, npt_rad=npt_rad, npt_azim=npt_azim, mask=mask, **kwargs
+    )
+    return output[1]
+
+
+def sigma_clip(z, azimuthal_integrator, npt_rad, npt_azim, mask=None, **kwargs):
+    """Perform the 2D integration and perform a sigm-clipping iterative
+     filter along each row. see the doc of scipy.stats.sigmaclip for the options.
+
+
+    Parameters
+    ----------
+    z : np.array()
+        Two-dimensional data array containing the signal.
+    azimuthal_integrator : pyFAI.azimuthal_integrator.AzimuthalIntegrator object
+        An AzimuthalIntegrator that is already initialised and used to calculate
+        the integral.
+    npt_rad: int
+         The number of points in the output pattern
+    npt_azim: int
+        The number of points in the radial space. Too few points may lead to huge rounding errors.
+    mask: Boolean Array
+        A boolean array with pixels to ignore
+    sum: bool
+        Returns the integrated intensity rather than the mean.
+    **kwargs :
+        Keyword arguments to be passed to ai.integrate2d
+
+    Returns
+    -------
+    tth : np.array()
+        One-dimensional scattering vector axis of z.
+    I : np.array()
+        One-dimensional azimuthal integral of z.
+    """
+    output = azimuthal_integrator.sigma_clip(
+        z, npt_rad=npt_rad, npt_azim=npt_azim, mask=mask, **kwargs
+    )
+    return output[1]
 
 
 def gain_normalise(z, dref, bref):
@@ -345,7 +313,7 @@ def gain_normalise(z, dref, bref):
     return ((z - dref) / (bref - dref)) * np.mean((bref - dref))
 
 
-def remove_dead(z, deadpixels, deadvalue="average", d=1):
+def remove_dead(z, deadpixels):
     """Remove dead pixels from experimental electron diffraction patterns.
 
     Parameters
@@ -355,10 +323,6 @@ def remove_dead(z, deadpixels, deadvalue="average", d=1):
     deadpixels : np.array()
         Array containing the array indices of dead pixels in the diffraction
         pattern.
-    deadvalue : str
-        Specify how deadpixels should be treated, options are;
-            'average': takes the average of adjacent pixels
-            'nan':  sets the dead pixel to nan
 
     Returns
     -------
@@ -366,26 +330,14 @@ def remove_dead(z, deadpixels, deadvalue="average", d=1):
         Two-dimensional data array containing z with dead pixels removed.
     """
     z_bar = np.copy(z)
-    if deadvalue == "average":
-        for (i, j) in deadpixels:
-            neighbours = z[i - d : i + d + 1, j - d : j + d + 1].flatten()
-            z_bar[i, j] = np.mean(neighbours)
-
-    elif deadvalue == "nan":
-        for (i, j) in deadpixels:
-            z_bar[i, j] = np.nan
-    else:
-        raise NotImplementedError(
-            "The method specified is not implemented. "
-            "See documentation for available "
-            "implementations."
-        )
+    for (i, j) in deadpixels:
+        z_bar[i, j] = (z[i - 1, j] + z[i + 1, j] + z[i, j - 1] + z[i, j + 1]) / 4
 
     return z_bar
 
 
 def convert_affine_to_transform(D, shape):
-    """ Converts an affine transform on a diffraction pattern to a suitable
+    """Converts an affine transform on a diffraction pattern to a suitable
     form for skimage.transform.warp()
 
     Parameters
@@ -445,9 +397,9 @@ def apply_transformation(z, transformation, keep_dtype, order=1, *args, **kwargs
     -----
     Generally used in combination with pyxem.expt_utils.convert_affine_to_transform
     """
-    if keep_dtype == False:
+    if keep_dtype is False:
         trans = tf.warp(z, transformation, order=order, *args, **kwargs)
-    if keep_dtype == True:
+    if keep_dtype is True:
         trans = tf.warp(
             z, transformation, order=order, preserve_range=True, *args, **kwargs
         )
@@ -477,68 +429,6 @@ def regional_filter(z, h):
     return z - dilated
 
 
-def subtract_background_dog(z, sigma_min, sigma_max):
-    """Difference of gaussians method for background removal.
-
-    Parameters
-    ----------
-    sigma_max : float
-        Large gaussian blur sigma.
-    sigma_min : float
-        Small gaussian blur sigma.
-
-    Returns
-    -------
-        Denoised diffraction pattern as np.array
-    """
-    blur_max = ndi.gaussian_filter(z, sigma_max)
-    blur_min = ndi.gaussian_filter(z, sigma_min)
-
-    return np.maximum(np.where(blur_min > blur_max, z, 0) - blur_max, 0)
-
-
-def subtract_background_median(z, footprint):
-    """Remove background using a median filter.
-
-    Parameters
-    ----------
-    footprint : int
-        size of the window that is convoluted with the array to determine
-        the median. Should be large enough that it is about 3x as big as the
-        size of the peaks.
-
-    Returns
-    -------
-        Pattern with background subtracted as np.array
-    """
-
-    selem = morphology.square(footprint)
-    # skimage only accepts input image as uint16
-    bg_subtracted = z - filters.median(z.astype(np.uint16), selem).astype(z.dtype)
-
-    return np.maximum(bg_subtracted, 0)
-
-
-def subtract_reference(z, bg):
-    """Subtracts background using a user-defined background pattern.
-
-    Parameters
-    ----------
-    z : np.array()
-        Two-dimensional data array containing signal.
-    bg: array()
-        User-defined diffraction pattern to be subtracted as background.
-
-    Returns
-    -------
-    im : np.array()
-        Two-dimensional data array containing signal with background removed.
-    """
-    im = z.astype(np.float64) - bg
-    im = np.where(im > 0, im, 0)
-    return im
-
-
 def circular_mask(shape, radius, center=None):
     """Produces a mask of radius 'r' centered on 'center' of shape 'shape'.
 
@@ -661,7 +551,7 @@ def find_beam_center_interpolate(z, sigma, upsample_factor, kind):
     Returns
     -------
     center : np.array
-        np.array containing indices of estimated direct beam positon.
+        np.array, [y, x] containing indices of estimated direct beam positon
     """
     xx = np.sum(z, axis=1)
     yy = np.sum(z, axis=0)
@@ -669,7 +559,7 @@ def find_beam_center_interpolate(z, sigma, upsample_factor, kind):
     cx = _find_peak_max(xx, sigma, upsample_factor=upsample_factor, kind=kind)
     cy = _find_peak_max(yy, sigma, upsample_factor=upsample_factor, kind=kind)
 
-    center = np.array([cx, cy])
+    center = np.array([cy, cx])
     return center
 
 
@@ -685,10 +575,10 @@ def find_beam_center_blur(z, sigma):
     Returns
     -------
     center : np.array
-        np.array containing indices of estimated direct beam positon.
+        np.array [y, x] containing indices of estimated direct beam positon.
     """
     blurred = ndi.gaussian_filter(z, sigma, mode="wrap")
-    center = np.unravel_index(blurred.argmax(), blurred.shape)
+    center = np.unravel_index(blurred.argmax(), blurred.shape)[::-1]
     return np.array(center)
 
 
@@ -711,7 +601,7 @@ def find_beam_offset_cross_correlation(z, radius_start, radius_finish):
     Returns
     -------
     shift: np.array
-        np.array containing offset (from center) of the direct beam positon.
+        np.array [y, x] containing offset (from center) of the direct beam positon.
     """
     radiusList = np.arange(radius_start, radius_finish)
     errRecord = np.zeros_like(radiusList, dtype="single")
@@ -727,7 +617,7 @@ def find_beam_offset_cross_correlation(z, radius_start, radius_finish):
         hann2d = np.sqrt(np.outer(h0, h1))
         ref = hann2d * ref
         im = hann2d * z
-        shift, error, diffphase = register_translation(ref, im, 10)
+        shift, error, diffphase = phase_cross_correlation(ref, im, upsample_factor=10)
         errRecord[ind] = error
         index_min = np.argmin(errRecord)
 
@@ -739,8 +629,9 @@ def find_beam_offset_cross_correlation(z, radius_start, radius_finish):
     hann2d = np.sqrt(np.outer(h0, h1))
     ref = hann2d * ref
     im = hann2d * z
-    shift, error, diffphase = register_translation(ref, im, 100)
+    shift, error, diffphase = phase_cross_correlation(ref, im, upsample_factor=100)
 
+    shift = shift[::-1]
     return shift - 0.5
 
 
@@ -799,13 +690,14 @@ def investigate_dog_background_removal_interactive(
 
     for i, std_dev_max in enumerate(tqdm(std_dev_maxs, leave=False)):
         for j, std_dev_min in enumerate(std_dev_mins):
-            gauss_processed[i, j] = sample_dp.remove_background(
-                "gaussian_difference",
-                sigma_min=std_dev_min,
-                sigma_max=std_dev_max,
+            gauss_processed[i, j] = sample_dp.subtract_diffraction_background(
+                "difference of gaussians",
+                lazy_result=False,
+                min_sigma=std_dev_min,
+                max_sigma=std_dev_max,
                 show_progressbar=False,
             )
-    dp_gaussian = pxm.ElectronDiffraction2D(gauss_processed)
+    dp_gaussian = pxm.signals.ElectronDiffraction2D(gauss_processed)
     dp_gaussian.metadata.General.title = "Gaussian preprocessed"
     dp_gaussian.axes_manager.navigation_axes[0].name = r"$\sigma_{\mathrm{min}}$"
     dp_gaussian.axes_manager.navigation_axes[1].name = r"$\sigma_{\mathrm{max}}$"
